@@ -131,6 +131,7 @@ class SQLExecute(object):
                                 str(e).find("SQLSyntaxErrorException") != -1 or
                                 str(e).find("SQLException") != -1 or
                                 str(e).find("SQLDataException") != -1 or
+                                str(e).find("SQLTransactionRollbackException") != -1 or
                                 str(e).find('time data') != -1
                         ):
                             # SQL 语法错误
@@ -223,7 +224,6 @@ class SQLExecute(object):
                 for row in rowset:
                     m_row = []
                     for column in row:
-                        print("CONTENT2 = [" + column + "]")
                         if str(type(column)).find('JDBCClobClient') != -1:
                             m_row.append(column.getSubString(1, int(self.options["CLOB_LONG"])))
                         elif str(type(column)).find("Float") != -1:
